'use strict';

var tslib_es6 = require('../../../external/tslib/tslib.es6.js');
var clientSsm = require('@aws-sdk/client-ssm');
var common = require('@nestjs/common');
var constant = require('../../../shared/constant/config/constant.js');

exports.ParameterStoreService = class ParameterStoreService {
    client;
    constructor(client) {
        this.client = client;
    }
    async getParametersByPath(path, decryptParameters = false, recursiveLoading = false, verbose = false) {
        if (verbose)
            common.Logger.verbose(`Getting parameters from path: ${path}`, "ParameterStoreConfig");
        let allParameters = [];
        let nextParametersToken;
        do {
            const getParameters = new clientSsm.GetParametersByPathCommand({
                NextToken: nextParametersToken,
                Path: path,
                Recursive: recursiveLoading,
                WithDecryption: decryptParameters,
            });
            const { NextToken, Parameters = [] } = await this.client.send(getParameters);
            allParameters = [...allParameters, ...Parameters];
            nextParametersToken = NextToken;
        } while (nextParametersToken);
        if (verbose)
            common.Logger.verbose(`Found ${String(allParameters.length)} parameters`, "ParameterStoreConfig");
        return allParameters;
    }
};
exports.ParameterStoreService = tslib_es6.__decorate([
    common.Injectable(),
    tslib_es6.__param(0, common.Inject(constant.PARAMETER_STORE_SSM_CLIENT)),
    tslib_es6.__metadata("design:paramtypes", [clientSsm.SSMClient])
], exports.ParameterStoreService);
//# sourceMappingURL=parameter-store.service.js.map
