import { __decorate, __param, __metadata } from '../../../external/tslib/tslib.es6.js';
import { GetParametersByPathCommand, SSMClient } from '@aws-sdk/client-ssm';
import { Injectable, Inject, Logger } from '@nestjs/common';
import { PARAMETER_STORE_SSM_CLIENT } from '../../../shared/constant/config/constant.js';

let ParameterStoreService = class ParameterStoreService {
    client;
    constructor(client) {
        this.client = client;
    }
    async getParametersByPath(path, decryptParameters = false, recursiveLoading = false, verbose = false) {
        if (verbose)
            Logger.verbose(`Getting parameters from path: ${path}`, "ParameterStoreConfig");
        let allParameters = [];
        let nextParametersToken;
        do {
            const getParameters = new GetParametersByPathCommand({
                NextToken: nextParametersToken,
                Path: path,
                Recursive: recursiveLoading,
                WithDecryption: decryptParameters,
            });
            const { NextToken, Parameters = [] } = await this.client.send(getParameters);
            allParameters = [...allParameters, ...Parameters];
            nextParametersToken = NextToken;
        } while (nextParametersToken);
        if (verbose)
            Logger.verbose(`Found ${String(allParameters.length)} parameters`, "ParameterStoreConfig");
        return allParameters;
    }
};
ParameterStoreService = __decorate([
    Injectable(),
    __param(0, Inject(PARAMETER_STORE_SSM_CLIENT)),
    __metadata("design:paramtypes", [SSMClient])
], ParameterStoreService);

export { ParameterStoreService };
//# sourceMappingURL=parameter-store.service.js.map
